| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Data.Fmt.Ansi
Contents
Synopsis
- code :: (Semigroup m, IsString m) => SGR -> Fmt m s a -> Fmt m s a
- codes :: (Semigroup m, IsString m) => [SGR] -> Fmt m s a -> Fmt m s a
- erase :: (Semigroup m, IsString m) => Ordering -> Fmt m s a -> Fmt m s a
- reset :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- shift :: (Semigroup m, IsString m) => Either Int Int -> Fmt m s a -> Fmt m s a
- scroll :: (Semigroup m, IsString m) => Either Int Int -> Fmt m s a -> Fmt m s a
- blink :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- bold :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- faint :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- italic :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- underline :: (Semigroup m, IsString m) => Fmt m s a -> Fmt m s a
- dull :: (Semigroup m, IsString m) => Color -> ConsoleLayer -> Fmt m s a -> Fmt m s a
- vivid :: (Semigroup m, IsString m) => Color -> ConsoleLayer -> Fmt m s a -> Fmt m s a
- layer :: (Semigroup m, IsString m) => XColor -> ConsoleLayer -> Fmt m s a -> Fmt m s a
- palette :: (Semigroup m, IsString m) => Palette -> Fmt m s a -> Fmt m s a
- type Palette = (XColor, XColor)
- type XColor = Word8
- data Color
- data ConsoleLayer
Ansi terminal codes
codes :: (Semigroup m, IsString m) => [SGR] -> Fmt m s a -> Fmt m s a Source #
Wrap content with escape sequence to set and reset color of normal intensity.
Emphasis
Color
type Palette = (XColor, XColor) Source #
A simple palette consisting of a foreground and background color.
ANSI's eight standard colors. They come in two intensities, which are
controlled by ColorIntensity. Many terminals allow the colors of the
standard palette to be customised, so that, for example,
setSGR [ SetColor Foreground Vivid Green ] may not result in bright green
characters.
data ConsoleLayer #
ANSI colors can be set on three different layers
Constructors
| Foreground | |
| Background | |
| Underlining | Not widely supported. Since: ansi-terminal-types-1.1 |