| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Data.Fmt.Time
Synopsis
- time :: (IsString m, FormatTime a) => String -> Fmt1 m s a
- t :: (IsString m, ISO8601 a) => Fmt1 m s a
- hm :: (IsString m, FormatTime a) => Fmt1 m s a
- hms :: (IsString m, FormatTime a) => Fmt1 m s a
- day :: (IsString m, FormatTime a) => Fmt1 m s a
- day' :: (IsString m, FormatTime a) => Fmt1 m s a
- month :: (IsString m, FormatTime a) => Fmt1 m s a
- month' :: (IsString m, FormatTime a) => Fmt1 m s a
- year :: (IsString m, FormatTime a) => Fmt1 m s a
- unix :: (IsString m, FormatTime a) => Fmt1 m s a
- zone :: (IsString m, FormatTime a) => Fmt1 m s a
- secs :: IsString m => Int -> Fmt1 m s Double
- mins :: IsString m => Int -> Fmt1 m s Double
- hours :: IsString m => Int -> Fmt1 m s Double
- days :: IsString m => Int -> Fmt1 m s Double
- years :: IsString m => Int -> Fmt1 m s Double
Documentation
time :: (IsString m, FormatTime a) => String -> Fmt1 m s a Source #
A custom time formatter.
For example, the E.U. formatting convention is time "%Y-%m-%d %T %z"
Time
Duration
secs :: IsString m => Int -> Fmt1 m s Double Source #
Display to a given precision the absolute value time span in seconds.
mins :: IsString m => Int -> Fmt1 m s Double Source #
Display to a given precision the absolute value time span in minutes.
hours :: IsString m => Int -> Fmt1 m s Double Source #
Display to a given precision the absolute value time span in hours.